/*
    -- MAGMA (version 2.6.2) --
       Univ. of Tennessee, Knoxville
       Univ. of California, Berkeley
       Univ. of Colorado, Denver
       @date April 2022
*/

#ifndef MAGMA_CONFIG_H
#define MAGMA_CONFIG_H


// CUDA settings
#define MAGMA_HAVE_CUDA
#define MAGMA_CUDA_ARCH_MIN 520

// HIP settings
/* #undef MAGMA_HAVE_HIP */



#endif  // MAGMA_CONFIG_H
